# If there are this code in orther local have to use 
# from lazyearth.mainfile import objearth
# from lazyearth.mainfile import water

from lazyearth.mainfile import objearth
from lazyearth.mainfile import water
from lazyearth.mainfile import imagedataset

deving_by = 'tul kedsaro'

__version__ = '1.0.16'
print(f'Lazyearth version : {__version__} Krub')

